@@ -1,7 +1,7 @@
 //! HackRF One API.
 //!
 //! To get started take a look at [`HackRfOne::new`].
-#![doc(html_root_url = "https://docs.rs/hackrfone/0.1.0")]
+#![doc(html_root_url = "https://docs.rs/hackrfone/0.2.0")]
 #![cfg_attr(docsrs, feature(doc_cfg))]
 #![deny(missing_docs)]
 
@@ -89,7 +89,7 @@ impl From<TranscieverMode> for u16 {
 }
 
 /// HackRF One errors.
-#[derive(Debug)]
+#[derive(Debug, Copy, Clone, PartialEq, Eq)]
 pub enum Error {
     /// USB error.
     Usb(rusb::Error),
@@ -121,6 +121,14 @@ impl From<rusb::Error> for Error {
     }
 }
 
+impl std::fmt::Display for Error {
+    fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{:?}", self)
+    }
+}
+
+impl std::error::Error for Error {}
+
 /// Typestate for RX mode.
 #[derive(Debug)]
 pub struct RxMode;
@@ -343,6 +351,9 @@ impl<MODE> HackRfOne<MODE> {
 
     /// Enable the RX/TX RF amplifier.
     ///
+    /// In GNU radio this is used as the RF gain, where a value of 0 dB is off,
+    /// and a value of 14 dB is on.
+    ///
     /// # Example
     ///
     /// Disable the amplifier.
@@ -432,6 +443,20 @@ impl<MODE> HackRfOne<MODE> {
     /// Set the LNA (low noise amplifier) gain.
     ///
     /// Range 0 to 40dB in 8dB steps.
+    ///
+    /// This is also known as the IF gain.
+    ///
+    /// # Example
+    ///
+    /// Set the LNA gain to 16 dB (generally a reasonable gain to start with).
+    ///
+    /// ```no_run
+    /// use hackrfone::{HackRfOne, UnknownMode};
+    ///
+    /// let mut radio: HackRfOne<UnknownMode> = HackRfOne::new().unwrap();
+    /// radio.set_lna_gain(16)?;
+    /// # Ok::<(), hackrfone::Error>(())
+    /// ```
     pub fn set_lna_gain(&mut self, gain: u16) -> Result<(), Error> {
         if gain > 40 {
             Err(Error::Argument)
@@ -448,6 +473,21 @@ impl<MODE> HackRfOne<MODE> {
     /// Set the VGA (variable gain amplifier) gain.
     ///
     /// Range 0 to 62dB in 2dB steps.
+    ///
+    /// This is also known as the baseband (BB) gain.
+    ///
+    /// # Example
+    ///
+    /// Set the VGA gain to 16 dB (generally a reasonable gain to start with).
+    ///
+    ///
+    /// ```no_run
+    /// use hackrfone::{HackRfOne, UnknownMode};
+    ///
+    /// let mut radio: HackRfOne<UnknownMode> = HackRfOne::new().unwrap();
+    /// radio.set_vga_gain(16)?;
+    /// # Ok::<(), hackrfone::Error>(())
+    /// ```
     pub fn set_vga_gain(&mut self, gain: u16) -> Result<(), Error> {
         if gain > 62 {
             Err(Error::Argument)
@@ -545,8 +585,8 @@ impl HackRfOne<RxMode> {
     ///
     /// This uses a bulk transfer to get one MTU (maximum transmission unit)
     /// of data in a single shot.  The data format is pairs of signed 8-bit IQ.
-    /// Use the [`iq_to_cplx`] helper to convert the data to a more manageable
-    /// format.
+    /// Use the [`iq_to_cplx_i8`] or [`iq_to_cplx_f32`] helpes to convert the
+    /// data to a more manageable format.
     ///
     /// Unlike `libhackrf` this does not spawn a sampling thread.
     ///
@@ -562,7 +602,8 @@ impl HackRfOne<RxMode> {
     /// # Ok::<(), hackrfone::Error>(())
     /// ```
     ///
-    /// [`iq_to_cplx`]: crate::iq_to_cplx
+    /// [`iq_to_cplx_i8`]: crate::iq_to_cplx_i8
+    /// [`iq_to_cplx_f32`]: crate::iq_to_cplx_f32
     pub fn rx(&mut self) -> Result<Vec<u8>, Error> {
         const ENDPOINT: u8 = 0x81;
         const MTU: usize = 128 * 1024;
@@ -649,7 +690,7 @@ mod freq_params {
 /// Post-processing sample data.
 ///
 /// ```no_run
-/// use hackrfone::{iq_to_cplx, HackRfOne, RxMode, UnknownMode};
+/// use hackrfone::{iq_to_cplx_i8, HackRfOne, RxMode, UnknownMode};
 ///
 /// let mut radio: HackRfOne<UnknownMode> = HackRfOne::new().unwrap();
 /// let mut radio: HackRfOne<RxMode> = radio.into_rx_mode()?;
@@ -657,7 +698,7 @@ mod freq_params {
 /// radio.stop_rx()?;
 ///
 /// for iq in data.chunks_exact(2) {
-///     let cplx: num_complex::Complex32 = iq_to_cplx(iq[0], iq[1]);
+///     let cplx: num_complex::Complex<i8> = iq_to_cplx_i8(iq[0], iq[1]);
 ///     // .. do whatever you want with cplx here
 /// }
 ///
@@ -667,13 +708,56 @@ mod freq_params {
 /// Guide level explanation.
 ///
 /// ```
-/// use hackrfone::iq_to_cplx;
-/// use num_complex::Complex32;
+/// use hackrfone::iq_to_cplx_i8;
+/// use num_complex::Complex;
 ///
-/// assert_eq!(iq_to_cplx(255, 1), Complex32::new(-1.0, 1.0));
+/// assert_eq!(iq_to_cplx_i8(255, 1), Complex::new(-1, 1));
 /// ```
 #[cfg(feature = "num-complex")]
 #[cfg_attr(docsrs, doc(cfg(feature = "num-complex")))]
-pub fn iq_to_cplx(i: u8, q: u8) -> num_complex::Complex32 {
-    num_complex::Complex32::new(f32::from(i as i8), f32::from(q as i8))
+pub fn iq_to_cplx_i8(i: u8, q: u8) -> num_complex::Complex<i8> {
+    num_complex::Complex::new(i as i8, q as i8)
+}
+
+/// Convert an IQ sample pair to a floating point complex number.
+///
+/// Generally you will want to use [`iq_to_cplx_i8`] for storing or transfering
+/// data because the samples are 2-bytes in the native i8, vs 8-bytes in f32.
+///
+/// Floats are easier to work with for running samples through digital signal
+/// processing algorithms (e.g. discrete fourier transform) where the i8 can
+/// easily saturate.
+///
+/// # Example
+///
+/// Post-processing sample data.
+///
+/// ```no_run
+/// use hackrfone::{iq_to_cplx_f32, HackRfOne, RxMode, UnknownMode};
+///
+/// let mut radio: HackRfOne<UnknownMode> = HackRfOne::new().unwrap();
+/// let mut radio: HackRfOne<RxMode> = radio.into_rx_mode()?;
+/// let data: Vec<u8> = radio.rx()?;
+/// radio.stop_rx()?;
+///
+/// for iq in data.chunks_exact(2) {
+///     let cplx: num_complex::Complex<f32> = iq_to_cplx_f32(iq[0], iq[1]);
+///     // .. do whatever you want with cplx here
+/// }
+///
+/// # Ok::<(), hackrfone::Error>(())
+/// ```
+///
+/// Guide level explanation.
+///
+/// ```
+/// use hackrfone::iq_to_cplx_f32;
+/// use num_complex::Complex;
+///
+/// assert_eq!(iq_to_cplx_f32(255, 1), Complex::new(-1.0, 1.0));
+/// ```
+#[cfg(feature = "num-complex")]
+#[cfg_attr(docsrs, doc(cfg(feature = "num-complex")))]
+pub fn iq_to_cplx_f32(i: u8, q: u8) -> num_complex::Complex<f32> {
+    num_complex::Complex::new(i as i8 as f32, q as i8 as f32)
 }
